/*
*********************************************************************************************************
*                                              uC/OS-II
*                                        The Real-Time Kernel
*
*                    Copyright 1992-2021 Silicon Laboratories Inc. www.silabs.com
*
*                                 SPDX-License-Identifier: APACHE-2.0
*
*               This software is subject to an open source license and is distributed by
*                Silicon Laboratories Inc. pursuant to the terms of the Apache License,
*                    Version 2.0 available at www.apache.org/licenses/LICENSE-2.0.
*
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*
*                                 uC/OS-II Configuration File for V2.9x
*
* Filename : os_cfg.h
* Version  : V2.93.01
*********************************************************************************************************
*/

#ifndef OS_CFG_H
#define OS_CFG_H


                                       /* ---------------------- MISCELLANEOUS ----------------------- */
#define OS_APP_HOOKS_EN           0u   /* Application-defined hooks are called from the uC/OS-II hooks */
#define OS_ARG_CHK_EN             0u   /* Enable (1) or Disable (0) argument checking                  */
#define OS_CPU_HOOKS_EN           1u   /* uC/OS-II hooks are found in the processor port files         */

#define OS_DEBUG_EN               0u   /* Enable(1) debug variables                                    */

#define OS_EVENT_MULTI_EN         0u   /* Include code for OSEventPendMulti()                          */
#define OS_EVENT_NAME_EN          0u   /* Enable names for Sem, Mutex, Mbox and Q                      */

#define OS_LOWEST_PRIO           63u   /* Defines the lowest priority that can be assigned ...         */
                                       /* ... MUST NEVER be higher than 254!                           */

#define OS_MAX_EVENTS            10u   /* Max. number of event control blocks in your application      */
#define OS_MAX_FLAGS              5u   /* Max. number of Event Flag Groups    in your application      */
#define OS_MAX_MEM_PART           5u   /* Max. number of memory partitions                             */
#define OS_MAX_QS                 4u   /* Max. number of queue control blocks in your application      */
#define OS_MAX_TASKS             20u   /* Max. number of tasks in your application, MUST be >= 2       */

#define OS_SCHED_LOCK_EN          1u   /* Include code for OSSchedLock() and OSSchedUnlock()           */

#define OS_TICK_STEP_EN           0u   /* Enable tick stepping feature for uC/OS-View                  */
#define OS_TICKS_PER_SEC        1000u   /* Set the number of ticks in one second                        */

#define OS_TLS_TBL_SIZE           0u   /* Size of Thread-Local Storage Table                           */


                                       /* --------------------- TASK STACK SIZE ---------------------- */
#define OS_TASK_TMR_STK_SIZE    64    /* Timer      task stack size (# of OS_STK wide entries)        */
#define OS_TASK_STAT_STK_SIZE   64    /* Statistics task stack size (# of OS_STK wide entries)        */
#define OS_TASK_IDLE_STK_SIZE   64    /* Idle       task stack size (# of OS_STK wide entries)        */


                                       /* --------------------- TASK MANAGEMENT ---------------------- */
#define OS_TASK_CHANGE_PRIO_EN    0u   /*     Include code for OSTaskChangePrio()                      */
#define OS_TASK_CREATE_EN         1u   /*     Include code for OSTaskCreate()                          */
#define OS_TASK_CREATE_EXT_EN     0u   /*     Include code for OSTaskCreateExt()                       */
#define OS_TASK_DEL_EN            0u   /*     Include code for OSTaskDel()                             */
#define OS_TASK_NAME_EN           0u   /*     Enable task names                                        */
#define OS_TASK_PROFILE_EN        0u   /*     Include variables in OS_TCB for profiling                */
#define OS_TASK_QUERY_EN          0u   /*     Include code for OSTaskQuery()                           */
#define OS_TASK_REG_TBL_SIZE      0u   /*     Size of task variables array (#of INT32U entries)        */
#define OS_TASK_STAT_EN           0u   /*     Enable (1) or Disable(0) the statistics task             */
#define OS_TASK_STAT_STK_CHK_EN   0u   /*     Check task stacks from statistic task                    */
#define OS_TASK_SUSPEND_EN        1u   /*     Include code for OSTaskSuspend() and OSTaskResume()      */
#define OS_TASK_SW_HOOK_EN        1u   /*     Include code for OSTaskSwHook()                          */


                                       /* ----------------------- EVENT FLAGS ------------------------ */
#define OS_FLAG_EN                0u   /* Enable (1) or Disable (0) code generation for EVENT FLAGS    */
#define OS_FLAG_ACCEPT_EN         0u   /*     Include code for OSFlagAccept()                          */
#define OS_FLAG_DEL_EN            0u   /*     Include code for OSFlagDel()                             */
#define OS_FLAG_NAME_EN           0u   /*     Enable names for event flag group                        */
#define OS_FLAG_QUERY_EN          0u   /*     Include code for OSFlagQuery()                           */
#define OS_FLAG_WAIT_CLR_EN       0u   /* Include code for Wait on Clear EVENT FLAGS                   */
#define OS_FLAGS_NBITS            8u   /* Size in #bits of OS_FLAGS data type (8, 16 or 32)            */


                                       /* -------------------- MESSAGE MAILBOXES --------------------- */
#define OS_MBOX_EN                0u   /* Enable (1) or Disable (0) code generation for MAILBOXES      */
#define OS_MBOX_ACCEPT_EN         0u   /*     Include code for OSMboxAccept()                          */
#define OS_MBOX_DEL_EN            0u   /*     Include code for OSMboxDel()                             */
#define OS_MBOX_PEND_ABORT_EN     0u   /*     Include code for OSMboxPendAbort()                       */
#define OS_MBOX_POST_EN           0u   /*     Include code for OSMboxPost()                            */
#define OS_MBOX_POST_OPT_EN       0u   /*     Include code for OSMboxPostOpt()                         */
#define OS_MBOX_QUERY_EN          0u   /*     Include code for OSMboxQuery()                           */


                                       /* --------------------- MEMORY MANAGEMENT -------------------- */
#define OS_MEM_EN                 0u   /* Enable (1) or Disable (0) code generation for MEMORY MANAGER */
#define OS_MEM_NAME_EN            0u   /*     Enable memory partition names                            */
#define OS_MEM_QUERY_EN           0u   /*     Include code for OSMemQuery()                            */


                                       /* ---------------- MUTUAL EXCLUSION SEMAPHORES --------------- */
#define OS_MUTEX_EN               0u   /* Enable (1) or Disable (0) code generation for MUTEX          */
#define OS_MUTEX_ACCEPT_EN        0u   /*     Include code for OSMutexAccept()                         */
#define OS_MUTEX_DEL_EN           0u   /*     Include code for OSMutexDel()                            */
#define OS_MUTEX_QUERY_EN         0u   /*     Include code for OSMutexQuery()                          */


                                       /* ---------------------- MESSAGE QUEUES ---------------------- */
#define OS_Q_EN                   0u   /* Enable (1) or Disable (0) code generation for QUEUES         */
#define OS_Q_ACCEPT_EN            0u   /*     Include code for OSQAccept()                             */
#define OS_Q_DEL_EN               0u   /*     Include code for OSQDel()                                */
#define OS_Q_FLUSH_EN             0u   /*     Include code for OSQFlush()                              */
#define OS_Q_PEND_ABORT_EN        0u   /*     Include code for OSQPendAbort()                          */
#define OS_Q_POST_EN              0u   /*     Include code for OSQPost()                               */
#define OS_Q_POST_FRONT_EN        0u   /*     Include code for OSQPostFront()                          */
#define OS_Q_POST_OPT_EN          0u   /*     Include code for OSQPostOpt()                            */
#define OS_Q_QUERY_EN             0u   /*     Include code for OSQQuery()                              */


                                       /* ------------------------ SEMAPHORES ------------------------ */
#define OS_SEM_EN                 0u   /* Enable (1) or Disable (0) code generation for SEMAPHORES     */
#define OS_SEM_ACCEPT_EN          0u   /*    Include code for OSSemAccept()                            */
#define OS_SEM_DEL_EN             0u   /*    Include code for OSSemDel()                               */
#define OS_SEM_PEND_ABORT_EN      0u   /*    Include code for OSSemPendAbort()                         */
#define OS_SEM_QUERY_EN           0u   /*    Include code for OSSemQuery()                             */
#define OS_SEM_SET_EN             0u   /*    Include code for OSSemSet()                               */


                                       /* --------------------- TIME MANAGEMENT ---------------------- */
#define OS_TIME_DLY_HMSM_EN       1u   /*     Include code for OSTimeDlyHMSM()                         */
#define OS_TIME_DLY_RESUME_EN     0u   /*     Include code for OSTimeDlyResume()                       */
#define OS_TIME_GET_SET_EN        0u   /*     Include code for OSTimeGet() and OSTimeSet()             */
#define OS_TIME_TICK_HOOK_EN      0u   /*     Include code for OSTimeTickHook()                        */


                                       /* --------------------- TIMER MANAGEMENT --------------------- */
#define OS_TMR_EN                 0u   /* Enable (1) or Disable (0) code generation for TIMERS         */
#define OS_TMR_CFG_MAX            16u   /*     Maximum number of timers                                 */
#define OS_TMR_CFG_NAME_EN        1u   /*     Determine timer names                                    */
#define OS_TMR_CFG_WHEEL_SIZE     8u   /*     Size of timer wheel (#Spokes)                            */
#define OS_TMR_CFG_TICKS_PER_SEC 10u   /*     Rate at which timer management task runs (Hz)            */


                                       /* ---------------------- TRACE RECORDER ---------------------- */
#define OS_TRACE_EN               0u   /* Enable (1) or Disable (0) uC/OS-II Trace instrumentation     */
#define OS_TRACE_API_ENTER_EN     0u   /* Enable (1) or Disable (0) uC/OS-II Trace API enter instrum.  */
#define OS_TRACE_API_EXIT_EN      0u   /* Enable (1) or Disable (0) uC/OS-II Trace API exit  instrum.  */

//OS任务切换函数使用DPTR自动递增功能优化代码.大概节省1us时间
//注意这部分代码不能进行硬件仿真单步调试   
//因为STC8H的串口仿真和USB仿真都是monitor仿真，是需要运行仿真监控程序的
//仿真监控程序里面有使用DPTR相关的指令，会影响用户DPTR的自动递增功能
//配置为0：关闭DPTR自动递增功能
//配置为1：开启DPTR自动递增功能
#define DPTR_AUTO_INC             1

//使用双数据指针需要对DPS，DPL1，DPH1入栈
//使用双DPTR有注意事项：若需要单独使能AU1 或者AU0，则必须使用TA寄存器触发DPS 的保护机制。
//本移植不考虑单独使能，必须同时使能方式。不然中断对DPS出栈的时候需要单独处理，太麻烦了。
//通过修改string.h里面的函数测试，AU1 和AU0 同时使能方式，完全没有问题。
//配置为0，仅用DPTR0
//配置为1，使用双数据指针
#define USE_DUAL_DPTR             0

//若用户有外扩64K 的扩展RAM，则在访问XFR 和外部扩展RAM 时需要注意：
//访问XFR 时需要将EAXFR 寄存器位设置为1；
//访问地址范围在0FA00H~0FFFFH 的外部扩展RAM 时需要将EAXFR 设置为0；
//访问地址范围在0000H~0F9FFH 的外部扩展RAM 时，与EAXFR 设置的值无关
//也就是xdata大于64000B时需要处理
//配置为0：EAXFR一直是1，使能使能访问XFR
//配置为1：使用的xdata大于64000B，访问最后1536字节的xdata时需要将EAXFR设置为0。
#define ACCESS_FULL_64K_XDATA     0

#endif
